import { Knex } from 'knex';
export declare type SortingParam<FullEntityRow> = {
    column: keyof FullEntityRow & string;
    order?: 'desc' | 'asc';
};
export declare type RepositoryConfig<NewEntityRow, FullEntityRow, UpdatedEntityRow, Filters> = {
    tableName: string;
    idColumn: keyof FullEntityRow & string;
    defaultOrderBy?: SortingParam<FullEntityRow>[];
    columnsForCreate?: (keyof NewEntityRow & string)[];
    columnsForUpdate?: (keyof UpdatedEntityRow & string)[];
    columnsForFilters?: (keyof Filters & string)[];
    columnsToFetch?: (keyof FullEntityRow & string)[];
    columnsToFetchList?: (keyof FullEntityRow & string)[];
    columnsToFetchDetails?: (keyof FullEntityRow & string)[];
};
export declare type UpdateParams<FullEntityRow> = {
    timeout?: number;
    sorting?: SortingParam<FullEntityRow>[] | null;
};
export declare type CreateBulkParams = {
    chunkSize: number;
};
export declare type GetParams<RowType> = {
    columnsToFetch?: (keyof RowType & string)[];
    sorting?: SortingParam<RowType>[] | null;
};
export declare class AbstractRepository<NewEntityRow extends Record<string, any> = any, FullEntityRow extends NewEntityRow = any, UpdatedEntityRow extends Record<string, any> = Partial<NewEntityRow>, Filters extends Record<string, any> = Partial<FullEntityRow>> {
    protected readonly knex: Knex;
    protected readonly tableName: string;
    protected readonly columnsToFetch: string[];
    protected readonly columnsToFetchList: string[];
    protected readonly columnsToFetchDetails: string[];
    protected readonly idColumn: string;
    protected readonly defaultOrderBy?: SortingParam<FullEntityRow>[];
    private readonly columnsForCreate?;
    private readonly columnsForFilters?;
    private readonly columnsForUpdate?;
    constructor(knex: Knex, config: RepositoryConfig<NewEntityRow, FullEntityRow, UpdatedEntityRow, Filters>);
    create(newEntityRow: NewEntityRow, transactionProvider?: Knex.TransactionProvider): Promise<FullEntityRow>;
    createBulk(newEntityRows: NewEntityRow[], transactionProvider?: Knex.TransactionProvider, params?: CreateBulkParams): Promise<FullEntityRow[]>;
    createBulkNoReturning(newEntityRows: NewEntityRow[], transactionProvider?: Knex.TransactionProvider, params?: CreateBulkParams): Promise<void>;
    updateById(id: string | number, updatedFields: UpdatedEntityRow, transactionProvider?: Knex.TransactionProvider, updateConfig?: UpdateParams<UpdatedEntityRow>): Promise<FullEntityRow | undefined>;
    updateSingleByCriteria(filterCriteria: Filters, updatedFields: UpdatedEntityRow, transactionProvider?: Knex.TransactionProvider | null): Promise<FullEntityRow>;
    updateByCriteria(filterCriteria: Filters, updatedFields: UpdatedEntityRow, transactionProvider?: Knex.TransactionProvider | null, updateParams?: UpdateParams<UpdatedEntityRow>): Promise<FullEntityRow[]>;
    getById(id: string | number, transactionProvider?: Knex.TransactionProvider | null, params?: GetParams<FullEntityRow>): Promise<FullEntityRow | undefined>;
    getByIdForUpdate(id: string | number, transactionProvider: Knex.TransactionProvider, params?: GetParams<FullEntityRow>): Promise<FullEntityRow | undefined>;
    getByCriteria(filterCriteria?: Filters, transactionProvider?: Knex.TransactionProvider | null, params?: GetParams<FullEntityRow>): Promise<FullEntityRow[]>;
    getByCriteriaForUpdate(transactionProvider: Knex.TransactionProvider, filterCriteria?: Filters, params?: GetParams<FullEntityRow>): Promise<FullEntityRow[]>;
    getSingleByCriteria(filterCriteria: Filters, params?: GetParams<FullEntityRow>): Promise<FullEntityRow | undefined>;
    deleteById(id: string | number, transactionProvider?: Knex.TransactionProvider): Promise<void>;
    deleteByCriteria(filterCriteria: Filters, transactionProvider?: Knex.TransactionProvider): Promise<void>;
    createTransactionProvider(): Knex.TransactionProvider;
    commitTransaction(transactionProvider: Knex.TransactionProvider): Promise<void>;
    rollbackTransaction(transactionProvider: Knex.TransactionProvider): Promise<void>;
    getKnexOrTransaction(transactionProvider?: Knex.TransactionProvider | null): Promise<Knex>;
}
